@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2017-01-10'; # DATE
-our $VERSION = '0.43'; # VERSION
+our $DATE = '2017-01-11'; # DATE
+our $VERSION = '0.44'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1123,7 +1123,7 @@ _
                 );
         }
 
-        my ($dp_code1, $dp_code2);
+        my ($dp_code1, $dp_code2, $dp_code3);
         if ($args{pack_deps}) {
             require Module::DataPack;
             my $dp_res = Module::DataPack::datapack_modules(
@@ -1132,10 +1132,12 @@ _
             );
             return [500, "Can't datapack: $dp_res->[0] - $dp_res->[1]"]
                 unless $dp_res->[0] == 200;
-            ($dp_code1, $dp_code2) = $dp_res->[2] =~ /(.+?)^(__DATA__\n.+)/sm;
+            $dp_code2 = "";
+            ($dp_code1, $dp_code3) = $dp_res->[2] =~ /(.+?)^(__DATA__\n.+)/sm;
         } else {
             $dp_code1 = "";
             $dp_code2 = "";
+            $dp_code3 = "";
             for my $pkg (sort keys %{ $cd->{module_srcs} }) {
                 my $src = $cd->{module_srcs}{$pkg};
                 $dp_code2 .= "# BEGIN $pkg\n$src\n# END $pkg\n\n";
@@ -1159,6 +1161,7 @@ _
                 read_config        => 0, # TODO
                 #config_filename    => $args{config_filenames},
                 #config_dirs        => $args{config_dirs},
+                completer_script    => "_$cd->{script_name}",
             );
             return err($res, 500, "Can't generate POD") unless $res->[0] == 200;
             $pod = $res->[2];
@@ -1230,9 +1233,11 @@ _
 
             @l,
 
+            $dp_code2,
+
             defined $pod ? ("=pod\n\n", "=encoding UTF-8\n\n", $pod, "\n\n=cut\n\n") : (),
 
-            $dp_code2,
+            $dp_code3,
 
             ("### code_after_end\n", $args{code_after_end}, "\n") x !!$args{code_after_end},
         );
@@ -1286,7 +1291,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.43 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2017-01-10.
+This document describes version 0.44 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2017-01-11.
 
 =head1 SYNOPSIS
 
